==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/config/appconfiggroupwidget.h <==
#ifndef PLAYERCONFIGWIDGET_H44
#define PLAYERCONFIGWIDGET_H44

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include "appconfiggroup.h"

#include <qwidget.h>

class QButtonGroup;
class QGroupBox;
class QGridLayout;

namespace SubtitleComposer
{
	class AppConfigGroupWidget : public QWidget
	{
		Q_OBJECT

		public:
			AppConfigGroupWidget( const AppConfigGroup& configGroup, QWidget* parent=0 );
			virtual ~AppConfigGroupWidget();

			const AppConfigGroup& configGroup();

		signals:

			void settingsChanged();

		public slots:

			void setConfigGroup( const AppConfigGroup& configGroup );

			void setControlsFromDefaults();
			virtual void setControlsFromConfig() = 0;
			virtual void setConfigFromControls() = 0;

		protected:

			QButtonGroup* createButtonGroup( const QString& title=QString::null, bool addToLayout=true );
			QGroupBox* createGroupBox( const QString& title=QString::null, bool addToLayout=true );
			QGridLayout* createGridLayout( QGroupBox* groupBox );

		protected:

			AppConfigGroup m_configGroup;

			QGridLayout* m_mainLayout;
	};
}

#endif

==> subtitlecomposer-0.4.3.tar.bz2: subtitlecomposer-0.4.3/src/config/appconfiggroupwidget.h <==
#ifndef PLAYERCONFIGWIDGET_H44
#define PLAYERCONFIGWIDGET_H44

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include "appconfiggroup.h"

#include <qwidget.h>

class QButtonGroup;
class QGroupBox;
class QGridLayout;

namespace SubtitleComposer
{
	class AppConfigGroupWidget : public QWidget
	{
		Q_OBJECT

		public:
			AppConfigGroupWidget( const AppConfigGroup& configGroup, QWidget* parent=0 );
			virtual ~AppConfigGroupWidget();

			const AppConfigGroup& configGroup();

		signals:

			void settingsChanged();

		public slots:

			void setConfigGroup( const AppConfigGroup& configGroup );

			void setControlsFromDefaults();
			virtual void setControlsFromConfig() = 0;
			virtual void setConfigFromControls() = 0;

		protected:

			QButtonGroup* createButtonGroup( const QString& title=QString::null, bool addToLayout=true );
			QGridLayout* createGridLayout( QButtonGroup* buttonGroup );

		protected:

			AppConfigGroup m_configGroup;

			QGridLayout* m_mainLayout;
	};
}

#endif
